@@ -1,6 +1,7 @@
 """
 `class` parser
 """
+
 import ast
 from ast import (
     AnnAssign,
@@ -17,12 +18,12 @@ from functools import partial
 from itertools import filterfalse
 from operator import setitem
 
-import cdd.parse._inspect
 import cdd.parse.docstring
 import cdd.parse.function
+import cdd.parse.utils.parser_utils
 from cdd.ast_utils import NoneStr, find_ast_type, get_value, parse_to_scalar
 from cdd.docstring_parsers import _set_name_and_type
-from cdd.parse.parser_utils import get_source, ir_merge
+from cdd.parse.utils.class_utils import get_source
 from cdd.pure_utils import rpartial, simple_types
 from cdd.source_transformer import to_code
 
@@ -109,6 +110,7 @@ def class_(
     for e in body:
         if isinstance(e, AnnAssign):
             typ = to_code(e.annotation).rstrip("\n")
+            # print(ast.dump(e, indent=4))
             val = (
                 (
                     lambda v: {"default": NoneStr}
@@ -125,12 +127,12 @@ def class_(
                         )(to_code(v).rstrip("\n"))
                     }
                 )(get_value(get_value(e)))
-                if hasattr(e, "value")
+                if hasattr(e, "value") and e.value is not None
                 else {}
             )
 
             # if 'str' in typ and val: val["default"] = val["default"].strip("'")  # Unquote?
-            typ_default = dict(typ=typ, **val)
+            typ_default = {"typ": typ} if val is None else dict(typ=typ, **val)
 
             target_id = e.target.id.lstrip("*")
 
@@ -183,6 +185,7 @@ def class_(
 
     intermediate_repr.update(
         {
+            "name": class_name or class_def.name,
             "params": OrderedDict(
                 map(
                     partial(
@@ -205,7 +208,11 @@ def class_(
     )
 
     if merge_inner_function is not None:
-        assert isinstance(class_def, ClassDef)
+        assert isinstance(
+            class_def, ClassDef
+        ), "Expected `ClassDef` got `{node_name!r}`".format(
+            node_name=type(class_def).__name__
+        )
 
         _merge_inner_function(
             class_def,
@@ -256,7 +263,7 @@ def _class_from_memory(
                                            {'typ': str, 'doc': Optional[str], 'default': Any}),)]] }
     :rtype: ```dict```
     """
-    ir = cdd.parse._inspect._inspect(
+    ir = cdd.parse.utils.parser_utils._inspect(
         class_def,
         class_name,
         parse_original_whitespace=parse_original_whitespace,
@@ -299,7 +306,7 @@ def _class_from_memory(
         merge_inner_function=merge_inner_function,
     )
 
-    ir_merge(ir, body_ir)
+    cdd.parse.utils.parser_utils.ir_merge(ir, body_ir)
     return ir
 
 
@@ -354,7 +361,7 @@ def _merge_inner_function(
             function_type=function_type,
             infer_type=infer_type,
         )
-        ir_merge(other=inner_ir, target=intermediate_repr)
+        cdd.parse.utils.parser_utils.ir_merge(other=inner_ir, target=intermediate_repr)
 
     return intermediate_repr
 
