@@ -10,6 +10,7 @@ from importlib import import_module
 from importlib.util import find_spec
 from inspect import getmodule
 from itertools import chain, count, filterfalse, islice, takewhile, zip_longest
+from json import JSONEncoder
 from keyword import iskeyword
 from operator import attrgetter, eq, itemgetter
 from os import environ, extsep, listdir, path
@@ -429,7 +430,7 @@ def all_dunder_for_module(name, exclude):
     """
     Generate `__all__` for a given module using single-level filename hierarchy exclusively
 
-    :param name: Module name
+    :param name: Module path
     :type name: ```str```
 
     :param exclude: Strings to exclude
@@ -794,6 +795,39 @@ def get_module(name, package=None, extra_symbols=None):
             raise
 
 
+def find_module_filepath(module_name, submodule_name):
+    """
+    Find module's file location without first importing it
+
+    :param module_name: Module name, e.g., "cdd.tests"
+    :type: ```str```
+
+    :param submodule_name: Submodule name, e.g., "test_pure_utils"
+    :type: ```str```
+
+    :return: Module location
+    :rpath: ```str```
+    """
+    module_origin = find_spec(module_name).origin
+    module_parent = path.dirname(module_origin)
+
+    return next(
+        filter(
+            path.exists,
+            (
+                path.join(
+                    module_parent, submodule_name, "__init__{}py".format(path.extsep)
+                ),
+                path.join(module_parent, "{}{}py".format(submodule_name, path.extsep)),
+                path.join(
+                    module_parent, submodule_name, "__init__{}py".format(path.extsep)
+                ),
+            ),
+        ),
+        module_origin,
+    )
+
+
 def count_chars_from(
     s, sentinel_char_unseen, char, end, s_len=len, start_idx=0, char_f=None
 ):
@@ -985,6 +1019,20 @@ def set_item(obj, key, val):
     return obj
 
 
+class SetEncoder(JSONEncoder):
+    """
+    JSON encoder that supports `set`s
+    """
+
+    def default(self, obj):
+        """
+        Handle `set` by giving a sorted list in its place
+        """
+        return (sorted if isinstance(obj, set) else partial(JSONEncoder.default, self))(
+            obj
+        )
+
+
 def no_magic_dir2attr(p_object):
     """
     Dictionary of `dir` without the __ prefix magics (also without _ prefix)
@@ -1004,10 +1052,52 @@ def no_magic_dir2attr(p_object):
     }
 
 
+def pascal_to_upper_camelcase(s):
+    """
+    Transform pascal input to upper camelcase
+
+    :param s: Pascal cased string
+    :type s: ```str```
+
+    :return: Upper camel case string
+    :rtype: ```str```
+    """
+    return "".join(filterfalse(str.isspace, s.title().replace("_", "")))
+
+
+def upper_camelcase_to_pascal(s):
+    """
+    Transform upper camelcase input to pascal case
+
+    :param s: Upper camel case string
+    :type s: ```str```
+
+    :return: Pascal cased string
+    :rtype: ```str```
+    """
+    return "_".join(
+        map(
+            str.lower,
+            "".join((" {}".format(c) if c.isupper() else c) for c in s)
+            .lstrip(" ")
+            .split(" "),
+        )
+    )
+
+
 omit_whitespace = rpartial(str.translate, str.maketrans({" ": "", "\n": "", "\t": ""}))
 
 sanitise_emit_name = dict(
-    **{typ: typ for typ in ("function", "sqlalchemy", "sqlalchemy_table")},
+    **{
+        typ: typ
+        for typ in (
+            "function",
+            "json_schema",
+            "pydantic",
+            "sqlalchemy",
+            "sqlalchemy_table",
+        )
+    },
     **{"class": "class_", "argparse": "argparse_function"}
 ).__getitem__
 
@@ -1019,6 +1109,7 @@ __all__ = [
     "PY3_8",
     "PY_GTE_3_8",
     "PY_GTE_3_9",
+    "SetEncoder",
     "all_dunder_for_module",
     "assert_equal",
     "balanced_parentheses",
@@ -1031,6 +1122,7 @@ __all__ = [
     "emit_separating_tabs",
     "filename_from_mod_or_filename",
     "fill",
+    "find_module_filepath",
     "get_module",
     "identity",
     "indent_all_but_first",
@@ -1045,6 +1137,7 @@ __all__ = [
     "omit_whitespace",
     "paren_wrap_code",
     "parse_comment_from_line",
+    "pascal_to_upper_camelcase",
     "pluralise",
     "pp",
     "quote",
@@ -1061,5 +1154,6 @@ __all__ = [
     "tab",
     "unquote",
     "update_d",
+    "upper_camelcase_to_pascal"
     # "previous_line_range",
 ]
